<?php

namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\BusinessPartnerService;
use FM\Traits\TResponse;


class BusinessPartnerController extends FMCrud {

    use TResponse;

    protected $BusinessPartnerService;

    public function __construct($crudService, $environment, BusinessPartnerService $BusinessPartnerService) {
        parent::__construct($crudService, $environment);
        $this->BusinessPartnerService = $BusinessPartnerService;
    }

    public function getBusinessPartner(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getBusinessPartner();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getOperator(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getOperator();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPartnerClassification(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getPartnerClassification();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTypeOfPartner(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getTypeOfPartner();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getMarketSegment(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getMarketSegment();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getBranchOfActivity(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getBranchOfActivity();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTypeOfActivity(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getTypeOfActivity();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getCountry(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getCountry();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getState(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getState($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getCity(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getCity($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDistrict(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getDistrict($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findCodeDistrict(DTO\Request $request, DTO\Response $response) {

        $codeFound = $this->BusinessPartnerService->findCodeDistrict($request->getParameters());
        $dtsVal = new DataSet('codeFound', $codeFound);
        $response->addDataSet($dtsVal);
    }

    public function getSpecificBusinessPartner(DTO\Request $request, DTO\Response $response) {

        $partnerFound = $this->BusinessPartnerService->getSpecificBusinessPartner($request->getParameters());
        $dtsVal = new DataSet('partnerFound', $partnerFound);
        $response->addDataSet($dtsVal);
    }

    public function insertNewBusinessPartner(DTO\Request $request, DTO\Response $response) {

        $partner = $this->BusinessPartnerService->insertNewBusinessPartner($request->getParameters());
        $dtsVal = new DataSet('partner', [$partner]);
        $response->addDataSet($dtsVal);
    }

    public function updateSpecificBusinessPartner(DTO\Request $request, DTO\Response $response) {

        $partnerFound = $this->BusinessPartnerService->updateSpecificBusinessPartner($request->getParameters());
        $dtsVal = new DataSet('partnerFound', [$partnerFound]);
        $response->addDataSet($dtsVal);
    }

    public function getBusinessPartnerAddress(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getBusinessPartnerAddress($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSpecificAddress(DTO\Request $request, DTO\Response $response) {

        $addressFound = $this->BusinessPartnerService->getSpecificAddress($request->getParameters());
        $dtsVal = new DataSet('addressFound', $addressFound);
        $response->addDataSet($dtsVal);
    }

    public function insertNewAddress(DTO\Request $request, DTO\Response $response) {

        $address = $this->BusinessPartnerService->insertNewAddress($request->getParameters());
        $dtsVal = new DataSet('address', [$address]);
        $response->addDataSet($dtsVal);
    }

    public function deleteAddress(DTO\Request $request, DTO\Response $response) {

        $address = $this->BusinessPartnerService->deleteAddress($request->getParameters());
        $dtsVal = new DataSet('address', [$address]);
        $response->addDataSet($dtsVal);
    }

    public function updateAddress(DTO\Request $request, DTO\Response $response) {

        $address = $this->BusinessPartnerService->updateAddress($request->getParameters());
        $dtsVal = new DataSet('address', [$address]);
        $response->addDataSet($dtsVal);
    }

    // --------- FUNÇÕES DE COMUNICAÇÃO -----------------------
    public function getWayOfCommunication(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getWayOfCommunication($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getListWaysOfCommunication(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getListWaysOfCommunication();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSpecificWayOfCommunication(DTO\Request $request, DTO\Response $response) {

        $communicFound = $this->BusinessPartnerService->getSpecificWayOfCommunication($request->getParameters());
        $dtsVal = new DataSet('communicFound', $communicFound);
        $response->addDataSet($dtsVal);
    }

    public function insertNewCommunicationData(DTO\Request $request, DTO\Response $response) {

        $communic = $this->BusinessPartnerService->insertNewCommunicationData($request->getParameters());
        $dtsVal = new DataSet('communic', [$communic]);
        $response->addDataSet($dtsVal);
    }

    public function deleteWayOfCommunication(DTO\Request $request, DTO\Response $response) {

        $communic = $this->BusinessPartnerService->deleteWayOfCommunication($request->getParameters());
        $dtsVal = new DataSet('communic', [$communic]);
        $response->addDataSet($dtsVal);
    }

    public function updateWayOfCommunication(DTO\Request $request, DTO\Response $response) {

        $communic = $this->BusinessPartnerService->updateWayOfCommunication($request->getParameters());
        $dtsVal = new DataSet('communic', [$communic]);
        $response->addDataSet($dtsVal);
    }

    // --------- FUNÇÕES DE INTERLOCUTORES -----------------------
    public function getSectors(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getSectors();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPositionsOfInterlocutors(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getPositionsOfInterlocutors();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getInterlocutors(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getInterlocutors($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSpecificInterlocutor(Request $request, Response $response){

        $interFound = $this->BusinessPartnerService->getSpecificInterlocutor($request->getParameters());
        $dtsVal = new DataSet('interFound', $interFound);
        $response->addDataSet($dtsVal);
    }

    public function insertNewInterlocutor(Request $request, Response $response){

        $interlocutor = $this->BusinessPartnerService->insertNewInterlocutor($request->getParameters());
        $dtsVal = new DataSet('interlocutor', [$interlocutor]);
        $response->addDataSet($dtsVal);
    }

    public function deleteInterlocutor(Request $request, Response $response){

        $interlocutor = $this->BusinessPartnerService->deleteInterlocutor($request->getParameters());
        $dtsVal = new DataSet('interlocutor', [$interlocutor]);
        $response->addDataSet($dtsVal);
    }

    public function updateInterlocutor(Request $request, Response $response){

        $interlocutor = $this->BusinessPartnerService->updateInterlocutor($request->getParameters());
        $dtsVal = new DataSet('interlocutor', [$interlocutor]);
        $response->addDataSet($dtsVal);
    }

    // --------- FUNÇÕES DE DADOS BANCÁRIOS -----------------------
    public function getBankDetails(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getBankDetails($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getBanks(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getBanks();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getAgencies(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getAgencies($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getCheckingAccount(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getCheckingAccount($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTypeOfCheckingAccount(Request $request, Response $response){
        try {
            $data = $this->BusinessPartnerService->getTypeOfCheckingAccount();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getSpecificBankDetails(Request $request, Response $response){

        $detailsFound = $this->BusinessPartnerService->getSpecificBankDetails($request->getParameters());
        $dtsVal = new DataSet('detailsFound', $detailsFound);
        $response->addDataSet($dtsVal);
    }

    public function insertNewBankDetails(Request $request, Response $response){

        $bank = $this->BusinessPartnerService->insertNewBankDetails($request->getParameters());
        $dtsVal = new DataSet('bank', [$bank]);
        $response->addDataSet($dtsVal);
    }

    public function deleteBankDetails(Request $request, Response $response){

        $bank = $this->BusinessPartnerService->deleteBankDetails($request->getParameters());
        $dtsVal = new DataSet('bank', [$bank]);
        $response->addDataSet($dtsVal);
    }

    public function updateBankDetails(Request $request, Response $response){

        $bank = $this->BusinessPartnerService->updateBankDetails($request->getParameters());
        $dtsVal = new DataSet('bank', [$bank]);
        $response->addDataSet($dtsVal);
    }

    public function getBranches(Request $request, Response $response){
         try {
            $data = $this->BusinessPartnerService->getBranches();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getInvoiceSeries(Request $request, Response $response){
         try {
            $data = $this->BusinessPartnerService->getInvoiceSeries();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getBillingParameter(Request $request, Response $response){

        $parameter = $this->BusinessPartnerService->getBillingParameter($request->getParameters());
        $dtsVal = new DataSet('parameter', $parameter);
        $response->addDataSet($dtsVal);
    }

    public function billingParameter(Request $request, Response $response){

        $parameter = $this->BusinessPartnerService->billingParameter($request->getParameters());
        $dtsVal = new DataSet('parameter', [$parameter]);
        $response->addDataSet($dtsVal);
    }

    public function sendImage(DTO\Request $request, DTO\Response $response) {

        $image = $this->BusinessPartnerService->sendImage($request->getParameters());
        $dtsVal = new DataSet('image', [$image]);
        $response->addDataSet($dtsVal);
    }

    public function getImagesLogotype(DTO\Request $request, DTO\Response $response) {

        $image = $this->BusinessPartnerService->getImagesLogotype($request->getParameters());
        $dtsVal = new DataSet('image', $image);
        $response->addDataSet($dtsVal);
    }
}

?>