<?php
namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\FuncoesService;
use FM\Traits\TResponse;

class FuncoesController extends FMCrud {
    
    use TResponse;
    protected $dataSourceName = 'fcm_checklistagend';
    protected $FuncoesService;
   
    public function __construct($crudService, $environment, FuncoesService $FuncoesService) {
        parent::__construct($crudService, $environment);
        $this->FuncoesService = $FuncoesService;
    }

    // Busca uma lista com todas funções com algumas informações
    public function getPositionsController(DTO\Request $request, DTO\Response $response) {
        try {
            $data = $this->FuncoesService->getPositionsService();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }   
    
    // Busca uma lista com todas as funções, só nome e id
    public function positionsListController(DTO\Request $request, DTO\Response $response) {
        $var = $this->FuncoesService->positionsListService();
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }
    
    public function createPositionController(DTO\Request $request, DTO\Response $response) {
        /* $var = $this->FuncoesService->createPositionService($nmperfilacesso, $idpermisssusuario, $idpermissstarefas, $idpermissslocais, $idpermissschecklist, $idpermisssrelatorios, $idpermisssgraficos, $idpermisssvistoria, $idpermissscalend, $iddirecionaqrcode,  $idtipodashboard);
        $dtsVal = new DataSet('info', array("message" => $var));
        $response->addDataSet($dtsVal); */


        try {
            $params = $request->getParameters();

            $nmperfilacesso = $params['params']['NMPERFILACESSO'];
            $nmperfilacesso = $params['params']['NMPERFILACESSO'];
            $idpermisssusuario = $params['params']['IDPERMISSSUSUARIO'];
            $idpermissstarefas = $params['params']['IDPERMISSSTAREFAS'];
            $idpermissslocais = $params['params']['IDPERMISSSLOCAIS'];
            $idpermissschecklist = $params['params']['IDPERMISSSCHECKLIST'];
            $idpermisssrelatorios = $params['params']['IDPERMISSSRELATORIOS'];
            $idpermisssgraficos = $params['params']['IDPERMISSSGRAFICOS'];
            $idpermisssvistoria = $params['params']['IDPERMISSSVISTORIA'];
            $idpermissscalend = $params['params']['IDPERMISSSCALEND'];
            $iddirecionaqrcode = $params['params']['IDDIRECIONAQRCODE'];
            $idtipodashboard = $params['params']['IDTIPODASHBOARD'];

            $data = $this->FuncoesService->createPositionService($nmperfilacesso, $idpermisssusuario, $idpermissstarefas, $idpermissslocais, $idpermissschecklist, $idpermisssrelatorios, $idpermisssgraficos, $idpermisssvistoria, $idpermissscalend, $iddirecionaqrcode,  $idtipodashboard);
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    // Busca uma função específica e todas suas informações
    public function getPositionInfoController(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();
        
        $var = $this->FuncoesService->getPositionInfoService($params["id"]);
        $dtsVal = new DataSet("info", $var);
        $response->addDataSet($dtsVal);
    }
    
    public function updatePositionController(DTO\Request $request, DTO\Response $response) {
        
        try {
            $params = $request->getParameters();
        
            $nrperfilacesso = $params['params']['NRPERFILACESSO'];
            $nmperfilacesso = $params['params']['NMPERFILACESSO'];
            $idpermisssusuario = $params['params']['IDPERMISSSUSUARIO'];
            $idpermissstarefas = $params['params']['IDPERMISSSTAREFAS'];
            $idpermissslocais = $params['params']['IDPERMISSSLOCAIS'];
            $idpermissschecklist = $params['params']['IDPERMISSSCHECKLIST'];
            $idpermisssrelatorios = $params['params']['IDPERMISSSRELATORIOS'];
            $idpermisssgraficos = $params['params']['IDPERMISSSGRAFICOS'];
            $idpermisssvistoria = $params['params']['IDPERMISSSVISTORIA'];
            $idpermissscalend = $params['params']['IDPERMISSSCALEND'];
            $iddirecionaqrcode = $params['params']['IDDIRECIONAQRCODE'];
            $idtipodashboard = $params['params']['IDTIPODASHBOARD'];
            
            $data = $this->FuncoesService->updatePositionService($nrperfilacesso, $nmperfilacesso, $idpermisssusuario, $idpermissstarefas, $idpermissslocais, $idpermissschecklist, $idpermisssrelatorios, $idpermisssgraficos, $idpermisssvistoria, $idpermissscalend, $iddirecionaqrcode, $idtipodashboard);
            $this->sendResponse($data, 200);

        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function deletePositionsController(DTO\Request $request, DTO\Response $response) {
        try {
            $data = $this->FuncoesService->deletePositionsService($request->getParameters());
            $this->sendResponse($data, 200);
        }  catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    // Busca qual as permissões para o usuário logado
    public function getPositionPermiss(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();
        $nrfuncionario = $params['id'];
        
        $var = $this->FuncoesService->getPositionPermiss($nrfuncionario);
        $dtsVal = new DataSet("info", $var);
        $response->addDataSet($dtsVal);
    }

}
?>