<?php

namespace FM\Service;

use FM\Factory\TarefaRecorrenteFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class TarefaRecorrenteService {

    protected $TarefaRecorrenteFactory;
    protected $CardsService;
    protected $Environment;
    protected $newCode;

    public function __construct (EntityManager $entityManager, TarefaRecorrenteFactory $TarefaRecorrenteFactory, Environment $Environment, NewCode $newCode) {
        $this->connection = $entityManager->getConnection();
        $this->TarefaRecorrenteFactory = $TarefaRecorrenteFactory;
        $this->Environment = $Environment;
        $this->newCode = $newCode;
    }
    
    public function tarefaRecorrente($param) {
        $this->connection->beginTransaction();

        try {
            forEach($param['HORAS'] as $dados){
                $paramDB = array(
                    "NRTAREFARECORRENTE"    => $this->newCode->getCodeByTableName("FCM_TAREFARECORRENTE ",  $this->Environment->getNrOrg(), 1, 10, true),
                    "NMTAREFA"              => $param['NMTAREFA'],
                    "TPLOCALTAREFA"         => null,
                    "LOCALTAREFA"           => implode(',',$param['LOCAL']),
                    "NRCHECKLIST"           => $param['CHECKLIST'],
                    "ITENSCHECKLIST"        => implode(',',$param['ITENSCHECK']),
                    "ESCOPOSTAREFA"         => null,
                    "ITENSTAREFA"           => implode(',',$param['TAREFA']),
                    "CRITERIOS"             => json_encode($param['CRITERIOS']),
                    "DIASSEMANA"            => $param['DIASSEMANA'],
                    "HORARIO"               => $dados['HORARIO'],
                    "DURACAO"               => $dados['DURACAO'],
                    "CDOPERTAREFA"          => $param['NRFUNCIONARIO'],
                    "CDOPERVISTORIA"        => $param['NRENCARREGADO'],
                    "IDCRIARVISTORIA"       => ($dados["VISTORIAAUTOMATICA"]) ? 'S' : 'N',
                    "NRORG"                 =>  $this->Environment->getNrOrg(),
                    "IDATIVO"               => 'S'
                );
                $this->TarefaRecorrenteFactory->tarefaRecorrente($paramDB);
            }
            $this->connection->commit();

        }  catch(\Exception $e) {
          $this->connection->rollback();
          throw $e;
        }
    }
    
    public function editarTarefaRecorrente($param){
        $this->connection->beginTransaction();

        try {

            $paramDB = array(
                "NRTAREFARECORRENTE"    => $param['NRTAREFARECORRENTE'],
                "DIASSEMANA"            => $param['DIASSEMANA'],
                "HORARIO"               => $param['HORARIO'],
                "DURACAO"               => $param['DURACAO'],
                "CDOPERTAREFA"          => $param['CDOPERTAREFA'],
                "CDOPERVISTORIA"        => $param['CDOPERVISTORIA'],
                "IDCRIARVISTORIA"       => ($param["CDOPERVISTORIA"] && $param["CDOPERVISTORIA"] != "") ? 'S' : 'N',
                "CDOPERULTATU"          => $this->Environment->getCdOperador()
            );

            $this->TarefaRecorrenteFactory->editarTarefaRecorrente($paramDB);
            $this->connection->commit();

        }  catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
          }
    }
    
    public function mudarStatusTarefaRecorrente($param){
        $this->connection->beginTransaction();
        
        try {
            $paramDB = array(
                "NRTAREFARECORRENTE" => $param['NRTAREFARECORRENTE'],
                "IDSITUACAO" => NULL,
            );
            if($param['TIPO'] == "PAUSAR") {
                $paramDB['IDSITUACAO'] = 2;
            }elseif($param['TIPO'] == "INICIAR") {
                $paramDB['IDSITUACAO'] = 1;
            }elseif($param['TIPO'] == "CANCELAR") {
                $paramDB['IDSITUACAO'] = 3;
            }
            
            $this->TarefaRecorrenteFactory->mudarStatusTarefaRecorrente($paramDB);
            
            switch ($paramDB['IDSITUACAO']) {
                case 1:
                    break;
                case 3:
                    $param["DATAFINAL"] = "";
                case 2:
                   // $this->deletarPeriodoTarefaRecorrente($param);
                    break;
            }
            
            $this->connection->commit();
            $response = "OK";
        }
        catch(\Exception $e) {
             $this->connection->rollback();
             $response = "Erro".utf8_decode($e->getErrorCode());
        }
        return $response;
    }
    
    public function getTarefaRecorrente($nr = NULL){
        $filter = [];
        
        $campos = array(
            "IDSITUACAO" => "FCM_TAREFARECORRENTE.IDSITUACAO",
            "NRTAREFARECORRENTE" => "FCM_TAREFARECORRENTE.NRTAREFARECORRENTE",
            "NRLOCALCLIENTE" => "FCM_LOCALCLI.NRLOCALCLIENTE",
            "NRCHECKLIST" => "FCM_TAREFARECORRENTE.NRCHECKLIST",
            "NRFUNCIONARIO" => "FCM_TAREFARECORRENTE.CDOPERTAREFA",
            "NRENCARREGADO" => "FCM_TAREFARECORRENTE.CDOPERVISTORIA",
            "NRTIPOLOCALCLI" => "FCM_TIPOLOCALCLI.NRTIPOLOCALCLI"
        );
        if((array_key_exists('in',$_REQUEST))){
            forEach($_REQUEST['in'] as $input){
                $filter[] = $campos[$input]." = ".$_REQUEST[$input];
            }
        }
        if(count($filter) > 0){
            $filter[0] = "WHERE ".$filter[0];
        }
        $filter = implode(" AND ",$filter);
        return $this->TarefaRecorrenteFactory->getDadosTarefaRecorrente($filter);
    }
    
    public function getAllDatasCreate($nr){
        return $this->TarefaRecorrenteFactory->getAllDatasCreate($nr);
    }
    
    public function getNameTarefas(){
        return $this->TarefaRecorrenteFactory->getNameTarefas();
    }
    
    public function setreinicioTarefa($dados){
        $this->TarefaRecorrenteFactory->setreinicioTarefa($dados);
    }
    
    public function deletarPeriodoTarefaRecorrente($param){
      
        $filtrar = "";
        if(!$param['DATAFINAL'] || $param['DATAFINAL'] == ""){
            $filtrar .= "AND DTHORATAREFAAGEND >= TO_DATE('".$param['DATAINICIAL']."' ,'DD/MM/YYYY')";
        } else {
            $filtrar .= "AND DTHORATAREFAAGEND BETWEEN TO_DATE('".$param['DATAINICIAL']."' ,'DD/MM/YYYY') AND TO_DATE('".$param['DATAFINAL']."' ,'DD/MM/YYYY')";
        }
        $this->TarefaRecorrenteFactory->deletarPeriodoTarefaRecorrente($param["NRTAREFARECORRENTE"],$filtrar);
    }
}

?>
